@@ -21,12 +21,12 @@ Take a look around F<examples/> folder for example tests that you can run
 agains your server.
 
 The general configuration should be done through the F<test-server.yaml> and should
-be managable by any non Perl awear admin (are there any?). Ofcourse you are free to
+be managable by any non Perl awear admin (are there any?). Of course you are free to
 put any other test that make sence for your server.
 
-The idea behind this is following. You run C<prove /etc/t> and everything is
+The idea behind this is following: You run C<prove /etc/t> and everything is
 fine. Server is up and running. Life is nice. Then somebody calls you at 3am...
-Ups what went wrong? You login to the server (if possible of course) and run
+Oups! What went wrong? You login to the server (if possible of course) and run
 the C<prove /etc/t> friend. Something failed? => fix it. Nothing failed?
 => write a test that will reveal that something is wrong && fix the problem
 of course ;). And then at 6am go happily to sleep again...
@@ -50,7 +50,7 @@ similar solutions like this...)
 use warnings;
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 METHODS
 
@@ -100,6 +100,16 @@ check running processes
 
 query dns server and check for the answers
 
+=item 02_resolv.conf.t
+
+query all nameserver-s in /etc/resolv.conf and make sure all are reachable.
+
+=item 02_time-sync.t
+
+compare local machine time with a ntp server to make sure both are in the sync.
+
+For the idea thanks to Emmanuel Rodriguez Santiago.
+
 =item 03_sites-ok.t
 
 check web sites
@@ -108,6 +118,12 @@ check web sites
 
 Check if the ports are open and if the service is responding.
 
+=item 03_cmd-output.t
+
+Check the output of the shell command with a regexp. Check the exit code.
+
+For the idea thanks to Aldo Calpini.
+
 =back
 
 =head1 sky
@@ -121,13 +137,18 @@ Any wishes || good ideas for general server tests should go here.
 Do you have any? Send it! Or even better send the .t file.
 
 	* check if all the interfaces has dns revers rr that properly resolves back
-	* check open ports
 	* I should write some easy example test for non perl admins
-	* check time synchronization (thanks Emmanuel)
-	* check if all nameservers in /etc/resolv.conf are reachable
-	* run command and check the output (thanks Aldo)
 	* file directory permissions for all relevant application directories
 	  (e.g. Is cache dir writeable for httpd) (thanks Peter Hartl)
+	* check folders if the files (logs?) didn't grow too huge
+	
+	* create Test::Server::Smoke to try examples on smoke testing servers
+
+=head1 LINKS
+
+L<http://testanything.org/>,
+L<http://en.wikipedia.org/wiki/Test_Anything_Protocol>
+and a book "Perl Testing: A Developer's Notebook"
 
 =head1 AUTHOR
 
